@@ -6,4 +6,4 @@ Created on Thu Nov 12 16:37:59 2020
 """
 import os
 def run():
-    exec(open("webapp.py").read())
+    exec(open("backtest/webapp.py").read())
